"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _dayjs = _interopRequireDefault(require("dayjs"));
var _localeData = _interopRequireDefault(require("dayjs/plugin/localeData"));
var _relativeTime = _interopRequireDefault(require("dayjs/plugin/relativeTime"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
_dayjs.default.extend(_localeData.default);
_dayjs.default.extend(_relativeTime.default);
class utils {
  constructor(_ref) {
    let {
      mode,
      locale,
      minimumDate,
      maximumDate,
      displayFullDays
    } = _ref;
    this.mode = mode;
    this.minimumDate = minimumDate;
    this.maximumDate = maximumDate;
    this.displayFullDays = displayFullDays;
    this.config = {
      calendarFormat: 'YYYY/MM/DD HH:mm',
      dateFormat: 'YYYY/MM/DD',
      timeFormat: 'HH:mm'
    };
    _dayjs.default.locale(locale);
  }
  getMonths = () => _dayjs.default.months();
  getMonthName = month => _dayjs.default.months()[month];
  getWeekdays = () => _dayjs.default.weekdays();
  getWeekdaysShort = () => _dayjs.default.weekdaysShort();
  getWeekdaysMin = () => _dayjs.default.weekdaysMin();
  getDateFormated = date => (0, _dayjs.default)(date).format(this.config.dateFormat);
  getTimeFormated = date => (0, _dayjs.default)(date).format(this.config.timeFormat);
  getFormated = date => (0, _dayjs.default)(date).format(this.config.calendarFormat);
  getFormatedValue = date => {
    if (this.mode === 'time') {
      const now = (0, _dayjs.default)().format('YYYY/MM/DD');
      return (0, _dayjs.default)(now + ' ' + date).format(this.config.calendarFormat);
    } else return (0, _dayjs.default)(date).format(this.config.calendarFormat);
  };
  getNow = () => {
    if (this.mode !== 'datetime') {
      const now = (0, _dayjs.default)().startOf('day');
      return now.format(this.config.calendarFormat);
    } else return (0, _dayjs.default)().format(this.config.calendarFormat);
  };
  getDateMonth = date => (0, _dayjs.default)(date).month();
  getDateYear = date => (0, _dayjs.default)(date).year();
  getDateHour = date => (0, _dayjs.default)(date).hour();
  getDateMinute = date => (0, _dayjs.default)(date).minute();
  getToday = () => (0, _dayjs.default)().format(this.config.dateFormat);
  getFormatedDate = (date, format) => (0, _dayjs.default)(date).format(format);
  getDate = date => (0, _dayjs.default)(date, this.config.calendarFormat);

  /**
   * Calculate month days array based on current date
   *
   * @param {DateType} datetime The current date that selected
   * @returns {IDayObject[]} days array based on current date
   */
  getMonthDays = datetime => {
    let date = this.getDate(datetime);
    const currentMonthDays = date.daysInMonth();
    const prevMonthDays = date.add(-1, 'month').daysInMonth();
    const firstDay = date.date(1);
    const dayOfMonth = firstDay.day() % 7;
    const prevDaysArray = Array.from({
      length: dayOfMonth
    }, (_, i) => i + (prevMonthDays - dayOfMonth + 1));
    const monthDaysOffset = dayOfMonth + currentMonthDays;
    const nextMonthDays = this.displayFullDays ? monthDaysOffset > 35 ? 42 - monthDaysOffset : 35 - monthDaysOffset : 0;
    const prevDays = this.displayFullDays ? prevDaysArray.map(day => {
      const thisDay = date.add(-1, 'month').date(day);
      let disabled = false;
      if (this.minimumDate) {
        disabled = thisDay < this.getDate(this.minimumDate);
      }
      if (this.maximumDate && !disabled) {
        disabled = thisDay > this.getDate(this.maximumDate);
      }
      return {
        text: day.toString(),
        day,
        date: this.getFormatedDate(thisDay, 'YYYY/MM/DD'),
        disabled,
        isCurrentMonth: false
      };
    }) : new Array(dayOfMonth);
    return [...prevDays, ...Array.from({
      length: currentMonthDays
    }, (_, i) => {
      const thisDay = date.date(i + 1);
      let disabled = false;
      if (this.minimumDate) {
        disabled = thisDay < this.getDate(this.minimumDate);
      }
      if (this.maximumDate && !disabled) {
        disabled = thisDay > this.getDate(this.maximumDate);
      }
      return {
        text: (i + 1).toString(),
        day: i + 1,
        date: this.getFormatedDate(thisDay, 'YYYY/MM/DD'),
        disabled,
        isCurrentMonth: true
      };
    }), ...Array.from({
      length: nextMonthDays
    }, (_, i) => {
      const thisDay = date.add(1, 'month').date(i + 1);
      let disabled = false;
      if (this.minimumDate) {
        disabled = thisDay < this.getDate(this.minimumDate);
      }
      if (this.maximumDate && !disabled) {
        disabled = thisDay > this.getDate(this.maximumDate);
      }
      return {
        text: (i + 1).toString(),
        day: i + 1,
        date: this.getFormatedDate(thisDay, 'YYYY/MM/DD'),
        disabled,
        isCurrentMonth: false
      };
    })];
  };
}
exports.default = utils;
//# sourceMappingURL=utils.js.map